@@ -22,14 +22,12 @@ _SPIRV_OP(Requires1_1, "Feature requires SPIR-V 1.1 or greater:")
 _SPIRV_OP(RequiresVersion, "Cannot fulfill SPIR-V version restriction:\n")
 _SPIRV_OP(RequiresExtension,
           "Feature requires the following SPIR-V extension:\n")
-_SPIRV_OP(InvalidMagicNumber,
-          "Invalid Magic Number.")
-_SPIRV_OP(InvalidVersionNumber,
-          "Invalid Version Number.")
+_SPIRV_OP(InvalidMagicNumber, "Invalid Magic Number.")
+_SPIRV_OP(InvalidVersionNumber, "Invalid Version Number.")
 _SPIRV_OP(UnspecifiedMemoryModel, "Unspecified Memory Model.")
 _SPIRV_OP(RepeatedMemoryModel, "Expects a single OpMemoryModel instruction.")
-_SPIRV_OP(DeprecatedExtension,
-          "Feature requires the following deprecated SPIR-V extension:\n")
+_SPIRV_OP(UnsupportedVarArgFunction,
+          "Variadic functions other than 'printf' are not supported in SPIR-V.")
 _SPIRV_OP(InvalidNumberOfOperands,
           "Number of operands does not match the expected count.")
 
