@@ -579,6 +579,13 @@ _SPIRV_OP(Subgroup2DBlockLoadTransposeINTEL, 6233)
 _SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
 _SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
 _SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
+_SPIRV_OP(ConditionalExtensionINTEL, 6248)
+_SPIRV_OP(ConditionalEntryPointINTEL, 6249)
+_SPIRV_OP(ConditionalCapabilityINTEL, 6250)
+_SPIRV_OP(SpecConstantTargetINTEL, 6251)
+_SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
+_SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
+_SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
